/* Copyright (C) 2023 FIAS Frankfurt Institute for Advanced Studies, Frankfurt / Main
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Felix Weiglhofer [committer] */
#ifndef CBM_ALGO_GLOBAL_RECO_RESULTS_H
#define CBM_ALGO_GLOBAL_RECO_RESULTS_H

#include <boost/serialization/access.hpp>

#include <vector>

#include "RecoResultsDescriptor.h"

class CbmStsDigi;
class CbmDigiEvent;
namespace cbm::algo::sts
{
  using Digi = CbmStsDigi;
}

namespace cbm::algo
{
  class RecoResults {

  public:
    // Place ctor / dtor in cxx, so that we can forward-declare the data classes and keep this header small.
    RecoResults(RecoResultsDescriptor descriptor);
    ~RecoResults();

    const RecoResultsDescriptor& Descriptor() const { return fDescriptor; }
    const std::vector<CbmDigiEvent>& Events() const { return fEvents; }
    std::vector<CbmDigiEvent>& Events() { return fEvents; }

  private:
    RecoResultsDescriptor fDescriptor;
    std::vector<CbmDigiEvent> fEvents;

    friend class boost::serialization::access;

    RecoResults();

    template<class Archive>
    void serialize(Archive& ar, const unsigned int /*version*/)
    {
      ar& fEvents;
    }
  };
}  // namespace cbm::algo

#endif
