/* Copyright (C) 2023 FIAS Frankfurt Institute for Advanced Studies, Frankfurt / Main
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Felix Weiglhofer [committer] */
#ifndef CBM_ALGO_GLOBAL_RECO_RESULTS_DESCRIPTOR_H
#define CBM_ALGO_GLOBAL_RECO_RESULTS_DESCRIPTOR_H

#include <boost/serialization/access.hpp>
#include <boost/serialization/version.hpp>

#include "Options.h"
#include "RecoParams.h"
#include "config/Yaml.h"

namespace cbm::algo
{
  class RecoResults;
}

namespace cbm::algo
{
  class RecoResultsDescriptor {
  public:
    RecoResultsDescriptor(Options options, RecoParams params) : fOptions(options), fParams(params) {}

    const RecoParams& Params() const { return fParams; }
    const Options& Opts() const { return fOptions; }

  private:  // members
    Options fOptions;
    RecoParams fParams;

  private:  // serialization
    friend class boost::serialization::access;
    friend class RecoResults;

    RecoResultsDescriptor() = default;

    template<class Archive>
    void save(Archive& ar, const unsigned int /*version*/) const
    {
      ar& fOptions;
      std::string yaml = config::Dump()(fParams);
      ar& yaml;
    }

    template<class Archive>
    void load(Archive& ar, const unsigned int /*version*/)
    {
      ar& fOptions;
      std::string yaml;
      ar& yaml;
      auto node = YAML::Load(yaml);
      fParams   = config::Read<RecoParams>(node);
    }
  };
}  // namespace cbm::algo

#endif  // CBM_ALGO_GLOBAL_RECO_RESULTS_DESCRIPTOR_H
